# MoaT command line

% start synopsis

This package contains the `moat` command line utility. It uses `asyncclick`
under the hood.

`moat` itself contains options for controlling verbosity and config file loading
and manipulation. everything else is (in deed, must be) handled with
plugins that supply sub-commands.

% end synopsis
